Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrAborted = errors.New("operation cancelled")
ErrAborted indicates that the user left the interactive UI without selecting.
Functions ¶
func BrowseSnapshots ¶
func BrowseSnapshots( snapshots []storage.Snapshot, title string, showRepo bool, deleteHandler DeleteHandler, ) error
BrowseSnapshots launches an interactive view for the provided snapshots.
Types ¶
type DeleteHandler ¶
DeleteHandler handles deleting a snapshot from persistent storage.
type SnapshotListMode ¶
type SnapshotListMode int
SnapshotListMode controls how the interactive UI behaves.
const ( // SnapshotListBrowse shows snapshots without returning a selection. SnapshotListBrowse SnapshotListMode = iota // SnapshotListSelect allows selecting a snapshot (used by restore). SnapshotListSelect )
Click to show internal directories.
Click to hide internal directories.